rem    -*- TCL -*-
rem    OutputFile: %2\%1.tdyn.dat.inf
rem    OutputFile: %2\%1.info
rem    ErrorFile: %2\%1.tdyn.dat.err
rem    WarningFile: %2\%1.tdyn.dat.war
rem    WarningFile: %2\%1.tdyn.warnings


rem TDYN DATAFILE:
move %1.dat.tdyn %1.tdyn.dat


rem RAMS DATAFILE:
rem copy %1.dat %1.dat
rem leave as is.


tcl
proc LaunchTdynAndRamSeries { basename dir problemtypedir } {
    global RunningProcess tcl_platform
    switch $::tcl_platform(platform) {
	"windows" {
	    set tdynexe tdyn.exe
	    set ramexe ramseries.exe
	}
	"default" {
	    set tdynexe tdyn
	    set ramexe ramseries
	}
    }
    
    foreach i [list .tdyn.dat.msh .tdyn.dat.ram.msh .tdyn.dat.res .tdyn.dat.ram.res .tdyn.dat.err .err .info .war] {
	file delete [file join $dir $basename$i]
    }
    
    set exe [file join $problemtypedir "exec" $tdynexe]
    set dat [file join $dir $basename.tdyn.dat]
    set out [file join $dir $basename.tdyn.dat.out]
    set err1 [file join $dir $basename.tdyn.dat.err]
    
    set pid1 [exec $exe -name $dat -3d > $out &]
    
    set RunningProcess running
    set ErrorInProcess "no"
    while 1 {
	if { $RunningProcess == "" } {
	    if { [isalive $pid1] } {  kill $pid1 }
	    vwait forever
	}
	if { ![isalive $pid1] } { break }
	if { ![isalive $pid1] & [file exists $err1] && [file size $err1] > 0 } {
	    set ErrorInProcess "yes"
	    break
	}
	after 200
	update
    }
    
    # Rename msh file
    if { [file exists [file join $dir $basename.tdyn.dat.ram.msh]] } {
	file copy -force "[file join $dir $basename.tdyn.dat.ram.msh]" "[file join $dir $basename.tdyn.dat.msh]"
    }
             

    set exe [file join $problemtypedir "exec" $ramexe]
    set dat [file join $dir $basename.dat]
    set err2 [file join $dir $basename.err]
    set info [file join $dir $basename.info]
    set warn [file join $dir $basename.warn]
    
	# Temporal change until new reading of results in the post process will be finished
	# -p Write mesh
	# -relements renumber elements starting in 1
    set pid2 [exec $exe -i $info -e $err2 -w $warn -p -relements -a $dat >> $err2 &]
    
    set RunningProcess running
    set ErrorInProcess "no"
    while 1 {
	if { $RunningProcess == "" } {
	    if { [isalive $pid2] } {  kill $pid2 }
	    vwait forever
	}
	if { ![isalive $pid2] } { break }
	if { ![isalive $pid2] & [file exists $err2] && [file size $err2] > 0 } {
	    set ErrorInProcess "yes"
	    break
	}
	after 200
	update
    }
    if { $ErrorInProcess=="no" } {
	if { ![file exists [file join $dir $basename.tdyn.dat.res]] || \
	    [file size [file join $dir $basename.tdyn.dat.res]] == 0 } {
	    set fout [open [file join $dir $basename.tdyn.dat.err] a]
	    puts $fout "Tdyn failed. Results are not available."
	    close $fout
	}
	if { ![file exists [file join $dir $basename.flavia.res]]  || \
	    [file size [file join $dir $basename.flavia.res]] == 0 } {
	    set fout [open [file join $dir $basename.err] a]
	    puts $fout "RamSeries failed. Results are not available."
	    close $fout
	}
    }
    foreach i [list .err .war] {
	set f [file join $dir $basename$i]
	if { [file exists $f] && [file size $f] > 0 } {
	    set fin [open $f r]
	    set fout [open [file join $dir $basename$i] a]
	    puts -nonewline $fout [read $fin]
	    close $fin
	    close $fout
	}
    }
	# Delete msh file
    if { [file exists [file join $dir $basename.tdyn.dat.msh]] } {
		file delete -force "[file join $dir $basename.tdyn.dat.msh]"
    }
	
#    set ftdyn [file join $dir $basename.tdyn.dat.res]
#    set fram [file join $dir $basename.flavia.res]
#    if { [file exists $ftdyn] && [file size $ftdyn] > 0 && \
#	[file exists $fram] && [file size $fram] > 0 } {
#	set fin [open $ftdyn r]
#	gets $fin
#	set fout [open $fram a]
#	puts -nonewline $fout [read $fin]
#	close $fin
#	close $fout
#	file delete $ftdyn
#    }
}

switch $::tcl_platform(platform) {
    "windows" { 
	foreach "- - basename dir problemtypedir -" $argv break
    }
    "default" { 
	foreach "basename dir problemtypedir" $argv break
    }
}
LaunchTdynAndRamSeries $basename $dir $problemtypedir